@@ -35,6 +35,12 @@
 #define FAUDIOCALL
 #endif
 
+#ifdef _MSC_VER
+#define FAUDIODEPRECATED(msg) __declspec(deprecated(msg))
+#else
+#define FAUDIODEPRECATED(msg) __attribute__((deprecated(msg)))
+#endif
+
 #include <stdint.h>
 #include <stddef.h>
 
@@ -146,6 +152,13 @@ typedef struct FAudioADPCMWaveFormat
 	FAudioWaveFormatEx wfx;
 	uint16_t wSamplesPerBlock;
 	uint16_t wNumCoef;
+
+	/* MSVC warns on empty arrays in structs */
+	#ifdef _MSC_VER
+	#pragma warning(push)
+	#pragma warning(disable: 4200)
+	#endif
+
 	FAudioADPCMCoefSet aCoef[];
 	/* MSADPCM has 7 coefficient pairs:
 	 * {
@@ -158,6 +171,10 @@ typedef struct FAudioADPCMWaveFormat
 	 *	{ 392, -232 }
 	 * }
 	 */
+
+	#ifdef _MSC_VER
+	#pragma warning(pop)
+	#endif
 } FAudioADPCMWaveFormat;
 
 typedef struct FAudioDeviceDetails
@@ -440,8 +457,8 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 
 #define FAUDIO_ABI_VERSION	0
 #define FAUDIO_MAJOR_VERSION	19
-#define FAUDIO_MINOR_VERSION	05
-#define FAUDIO_PATCH_VERSION	00
+#define FAUDIO_MINOR_VERSION	06
+#define FAUDIO_PATCH_VERSION	07
 
 #define FAUDIO_COMPILED_VERSION ( \
 	(FAUDIO_ABI_VERSION * 100 * 100 * 100) + \
@@ -450,7 +467,7 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 	(FAUDIO_PATCH_VERSION) \
 )
 
-FAUDIOAPI uint32_t FAudioLinkedVersion();
+FAUDIOAPI uint32_t FAudioLinkedVersion(void);
 
 /* FAudio Interface */
 
@@ -648,9 +665,24 @@ FAUDIOAPI uint32_t FAudio_StartEngine(FAudio *audio);
  */
 FAUDIOAPI void FAudio_StopEngine(FAudio *audio);
 
-/* This is where you'd push OperationSet changes if we actually supported them.
- * Don't bother with this function, sorry!
+/* Flushes a batch of FAudio calls compiled with a given "OperationSet" tag.
+ * This function is based on IXAudio2::CommitChanges from the XAudio2 spec.
+ * This is useful for pushing calls that need to be done perfectly in sync. For
+ * example, if you want to play two separate sources at the exact same time, you
+ * can call FAudioSourceVoice_Start with an OperationSet value of your choice,
+ * then call CommitChanges with that same value to start the sources together.
+ *
+ * OperationSet: Either a value known by you or FAUDIO_COMMIT_ALL
+ *
+ * Returns 0 on success.
  */
+FAUDIOAPI uint32_t FAudio_CommitOperationSet(
+	FAudio *audio,
+	uint32_t OperationSet
+);
+
+/* DO NOT USE THIS FUNCTION OR I SWEAR TO GOD */
+FAUDIODEPRECATED("This function will break your program! Use FAudio_CommitOperationSet instead!")
 FAUDIOAPI uint32_t FAudio_CommitChanges(FAudio *audio);
 
 /* Requests various bits of performance information from the engine.
